@@ -103,7 +103,7 @@
 */
 
 #include <util.h>
-/*@unused@*/ RCSID("$Id: macho-objfmt.c 1974 2007-09-21 16:37:01Z peter $");
+/*@unused@*/ RCSID("$Id: macho-objfmt.c 2035 2008-02-09 03:35:07Z peter $");
 
 /* optional: automatically prefix underscores to global exported symbols */
 /*#define AUTO_UNDERSCORE*/
@@ -1272,8 +1272,8 @@ macho_objfmt_add_default_section(yasm_object *object)
     macho_section_data *msd;
     int isnew;
 
-    retval = yasm_object_get_general(object, "LC_SEGMENT.__TEXT.__text", 0, 0, 1, 0,
-                                     &isnew, 0);
+    retval = yasm_object_get_general(object, "LC_SEGMENT.__TEXT.__text", 0, 1,
+                                     0, &isnew, 0);
     if (isnew) {
         msd = macho_objfmt_init_new_section(object, retval, ".text", 0);
         msd->segname = yasm__xstrdup("__TEXT");
@@ -1464,7 +1464,7 @@ macho_objfmt_section_switch(yasm_object *object, yasm_valparamhead *valparams,
     realname = yasm_xmalloc(strlen("LC_SEGMENT") + 1 + strlen(data.f_segname) + 1 +
                             strlen(f_sectname) + 1);
     sprintf(realname, "LC_SEGMENT.%s.%s", data.f_segname, f_sectname);
-    retval = yasm_object_get_general(object, realname, 0, align, 1, resonly,
+    retval = yasm_object_get_general(object, realname, align, 1, resonly,
                                      &isnew, line);
     yasm_xfree(realname);
 
@@ -1485,6 +1485,13 @@ macho_objfmt_section_switch(yasm_object *object, yasm_valparamhead *valparams,
     return retval;
 }
 
+static /*@observer@*/ /*@null@*/ yasm_symrec *
+macho_objfmt_get_special_sym(yasm_object *object, const char *name,
+                             const char *parser)
+{
+    return NULL;
+}
+
 static void
 macho_section_data_destroy(void *data)
 {
@@ -1548,7 +1555,8 @@ yasm_objfmt_module yasm_macho_LTX_objfmt = {
     macho_objfmt_output,
     macho_objfmt_destroy,
     macho_objfmt_add_default_section,
-    macho_objfmt_section_switch
+    macho_objfmt_section_switch,
+    macho_objfmt_get_special_sym
 };
 
 yasm_objfmt_module yasm_macho32_LTX_objfmt = {
@@ -1563,7 +1571,8 @@ yasm_objfmt_module yasm_macho32_LTX_objfmt = {
     macho_objfmt_output,
     macho_objfmt_destroy,
     macho_objfmt_add_default_section,
-    macho_objfmt_section_switch
+    macho_objfmt_section_switch,
+    macho_objfmt_get_special_sym
 };
 
 yasm_objfmt_module yasm_macho64_LTX_objfmt = {
@@ -1578,5 +1587,6 @@ yasm_objfmt_module yasm_macho64_LTX_objfmt = {
     macho_objfmt_output,
     macho_objfmt_destroy,
     macho_objfmt_add_default_section,
-    macho_objfmt_section_switch
+    macho_objfmt_section_switch,
+    macho_objfmt_get_special_sym
 };
