@@ -25,7 +25,7 @@
  * POSSIBILITY OF SUCH DAMAGE.
  */
 #include <util.h>
-RCSID("$Id: nasm-parse.c 1984 2007-09-21 18:16:28Z peter $");
+RCSID("$Id: nasm-parse.c 2045 2008-03-27 05:35:36Z peter $");
 
 #include <libyasm.h>
 
@@ -35,8 +35,8 @@ RCSID("$Id: nasm-parse.c 1984 2007-09-21 18:16:28Z peter $");
 
 typedef enum {
     NORM_EXPR,
-    DIR_EXPR,
-    DV_EXPR
+    DIR_EXPR,       /* Can't have seg:off or WRT anywhere */
+    DV_EXPR         /* Can't have registers anywhere */
 } expr_type;
 
 static yasm_bytecode *parse_line(yasm_parser_nasm *parser_nasm);
@@ -46,7 +46,7 @@ static yasm_bytecode *parse_times(yasm_parser_nasm *parser_nasm);
 static yasm_bytecode *parse_exp(yasm_parser_nasm *parser_nasm);
 static yasm_bytecode *parse_instr(yasm_parser_nasm *parser_nasm);
 static yasm_insn_operand *parse_operand(yasm_parser_nasm *parser_nasm);
-static yasm_effaddr *parse_memaddr(yasm_parser_nasm *parser_nasm);
+static yasm_insn_operand *parse_memaddr(yasm_parser_nasm *parser_nasm);
 static yasm_expr *parse_expr(yasm_parser_nasm *parser_nasm, expr_type type);
 static yasm_expr *parse_bexpr(yasm_parser_nasm *parser_nasm, expr_type type);
 static yasm_expr *parse_expr0(yasm_parser_nasm *parser_nasm, expr_type type);
@@ -64,7 +64,7 @@ static void nasm_parser_directive
 static void define_label(yasm_parser_nasm *parser_nasm, /*@only@*/ char *name,
                          int local);
 
-#define is_eol_tok(tok) ((tok) == '\n' || (tok) == 0)
+#define is_eol_tok(tok) ((tok) == 0)
 #define is_eol()        is_eol_tok(curtok)
 
 #define get_next_token()    (curtok = nasm_parser_lex(&curval, parser_nasm))
@@ -98,6 +98,7 @@ destroy_curtok_(yasm_parser_nasm *parser_nasm)
         case ID:
         case LOCAL_ID:
         case SPECIAL_ID:
+        case NONLOCAL_ID:
             yasm_xfree(curval.str_val);
             break;
         case STRING:
@@ -133,16 +134,14 @@ demand_eol_(yasm_parser_nasm *parser_nasm)
 }
 #define demand_eol() demand_eol_(parser_nasm)
 
-static int
-expect_(yasm_parser_nasm *parser_nasm, int token)
+static const char *
+describe_token(int token)
 {
     static char strch[] = "` '";
     const char *str;
 
-    if (curtok == token)
-        return 1;
-
     switch (token) {
+        case 0:                 str = "end of line"; break;
         case INTNUM:            str = "integer"; break;
         case FLTNUM:            str = "floating point value"; break;
         case DIRECTIVE_NAME:    str = "directive name"; break;
@@ -171,13 +170,24 @@ expect_(yasm_parser_nasm *parser_nasm, int token)
         case ID:                str = "identifier"; break;
         case LOCAL_ID:          str = ".identifier"; break;
         case SPECIAL_ID:        str = "..identifier"; break;
+        case NONLOCAL_ID:       str = "..@identifier"; break;
         case LINE:              str = "%line"; break;
         default:
             strch[1] = token;
             str = strch;
             break;
     }
-    yasm_error_set(YASM_ERROR_PARSE, "expected %s", str);
+
+    return str;
+}
+
+static int
+expect_(yasm_parser_nasm *parser_nasm, int token)
+{
+    if (curtok == token)
+        return 1;
+
+    yasm_error_set(YASM_ERROR_PARSE, "expected %s", describe_token(token));
     destroy_curtok();
     return 0;
 }
@@ -186,9 +196,19 @@ expect_(yasm_parser_nasm *parser_nasm, int token)
 void
 nasm_parser_parse(yasm_parser_nasm *parser_nasm)
 {
-    while (get_next_token() != 0) {
+    unsigned char *line;
+    while ((line = (unsigned char *)
+            yasm_preproc_get_line(parser_nasm->preproc)) != NULL) {
         yasm_bytecode *bc = NULL, *temp_bc;
-        
+
+        parser_nasm->s.bot = line;
+        parser_nasm->s.tok = line;
+        parser_nasm->s.ptr = line;
+        parser_nasm->s.cur = line;
+        parser_nasm->s.lim = line + strlen((char *)line)+1;
+        parser_nasm->s.top = parser_nasm->s.lim;
+
+        get_next_token();
         if (!is_eol()) {
             bc = parse_line(parser_nasm);
             demand_eol();
@@ -230,10 +250,10 @@ nasm_parser_parse(yasm_parser_nasm *parser_nasm)
         yasm_errwarn_propagate(parser_nasm->errwarns, cur_line);
 
         if (parser_nasm->save_input)
-            yasm_linemap_add_source(parser_nasm->linemap,
-                temp_bc,
-                (char *)parser_nasm->save_line[parser_nasm->save_last ^ 1]);
+            yasm_linemap_add_source(parser_nasm->linemap, temp_bc,
+                                    (char *)line);
         yasm_linemap_goto_next(parser_nasm->linemap);
+        yasm_xfree(line);
     }
 }
 
@@ -331,6 +351,7 @@ parse_line(yasm_parser_nasm *parser_nasm)
             return parse_times(parser_nasm);
         case ID:
         case SPECIAL_ID:
+        case NONLOCAL_ID:
         case LOCAL_ID:
         {
             char *name = ID_val;
@@ -457,7 +478,7 @@ parse_times(yasm_parser_nasm *parser_nasm)
     yasm_expr *multiple;
     yasm_bytecode *bc;
 
-    multiple = parse_expr(parser_nasm, DV_EXPR);
+    multiple = parse_bexpr(parser_nasm, DV_EXPR);
     if (!multiple) {
         yasm_error_set(YASM_ERROR_SYNTAX, N_("expression expected after %s"),
                        "TIMES");
@@ -508,7 +529,7 @@ parse_exp(yasm_parser_nasm *parser_nasm)
                         goto dv_done;
                     }
                 }
-                if ((e = parse_expr(parser_nasm, DV_EXPR)))
+                if ((e = parse_bexpr(parser_nasm, DV_EXPR)))
                     dv = yasm_dv_create_expr(e);
                 else {
                     yasm_error_set(YASM_ERROR_SYNTAX,
@@ -536,7 +557,7 @@ dv_done:
             unsigned int size = RESERVE_SPACE_val/8;
             yasm_expr *e;
             get_next_token();
-            e = parse_expr(parser_nasm, DV_EXPR);
+            e = parse_bexpr(parser_nasm, DV_EXPR);
             if (!e) {
                 yasm_error_set(YASM_ERROR_SYNTAX,
                                N_("expression expected after %s"), "RESx");
@@ -564,7 +585,7 @@ dv_done:
                 get_next_token();
             if (is_eol())
                 goto incbin_done;
-            start = parse_expr(parser_nasm, DV_EXPR);
+            start = parse_bexpr(parser_nasm, DV_EXPR);
             if (!start) {
                 yasm_error_set(YASM_ERROR_SYNTAX,
                                N_("expression expected for INCBIN start"));
@@ -576,8 +597,8 @@ dv_done:
                 get_next_token();
             if (is_eol())
                 goto incbin_done;
-            maxlen = parse_expr(parser_nasm, DV_EXPR);
-            if (!start) {
+            maxlen = parse_bexpr(parser_nasm, DV_EXPR);
+            if (!maxlen) {
                 yasm_error_set(YASM_ERROR_SYNTAX,
                     N_("expression expected for INCBIN maximum length"));
                 return NULL;
@@ -612,8 +633,14 @@ parse_instr(yasm_parser_nasm *parser_nasm)
             for (;;) {
                 yasm_insn_operand *op = parse_operand(parser_nasm);
                 if (!op) {
-                    yasm_error_set(YASM_ERROR_SYNTAX,
-                                   N_("expression syntax error"));
+                    if (insn->num_operands == 0)
+                        yasm_error_set(YASM_ERROR_SYNTAX,
+                                       N_("unexpected %s after instruction"),
+                                       describe_token(curtok));
+                    else
+                        yasm_error_set(YASM_ERROR_SYNTAX,
+                                       N_("expected operand, got %s"),
+                                       describe_token(curtok));
                     yasm_bc_destroy(bc);
                     return NULL;
                 }
@@ -634,8 +661,9 @@ parse_instr(yasm_parser_nasm *parser_nasm)
             uintptr_t prefix = PREFIX_val;
             get_next_token();
             bc = parse_instr(parser_nasm);
-            if (bc)
-                yasm_insn_add_prefix(yasm_bc_get_insn(bc), prefix);
+            if (!bc)
+                bc = yasm_arch_create_empty_insn(p_object->arch, cur_line);
+            yasm_insn_add_prefix(yasm_bc_get_insn(bc), prefix);
             return bc;
         }
         case SEGREG:
@@ -643,8 +671,9 @@ parse_instr(yasm_parser_nasm *parser_nasm)
             uintptr_t segreg = SEGREG_val;
             get_next_token();
             bc = parse_instr(parser_nasm);
-            if (bc)
-                yasm_insn_add_seg_prefix(yasm_bc_get_insn(bc), segreg);
+            if (!bc)
+                bc = yasm_arch_create_empty_insn(p_object->arch, cur_line);
+            yasm_insn_add_seg_prefix(yasm_bc_get_insn(bc), segreg);
             return bc;
         }
         default:
@@ -659,19 +688,18 @@ parse_operand(yasm_parser_nasm *parser_nasm)
     switch (curtok) {
         case '[':
         {
-            yasm_effaddr *ea;
             get_next_token();
-            ea = parse_memaddr(parser_nasm);
+            op = parse_memaddr(parser_nasm);
 
             expect(']');
             get_next_token();
 
-            if (!ea) {
+            if (!op) {
                 yasm_error_set(YASM_ERROR_SYNTAX,
                                N_("memory address expected"));
                 return NULL;
             }
-            return yasm_operand_create_mem(ea);
+            return op;
         }
         case SEGREG:
             op = yasm_operand_create_segreg(SEGREG_val);
@@ -730,19 +758,32 @@ parse_operand(yasm_parser_nasm *parser_nasm)
         }
         default:
         {
-            yasm_expr *e = parse_expr(parser_nasm, NORM_EXPR);
+            yasm_expr *e = parse_bexpr(parser_nasm, NORM_EXPR);
             if (!e)
                 return NULL;
-            return yasm_operand_create_imm(e);
+            if (curtok != ':')
+                return yasm_operand_create_imm(e);
+            else {
+                yasm_expr *off;
+                get_next_token();
+                off = parse_bexpr(parser_nasm, NORM_EXPR);
+                if (!off) {
+                    yasm_expr_destroy(e);
+                    return NULL;
+                }
+                op = yasm_operand_create_imm(off);
+                op->seg = e;
+                return op;
+            }
         }
     }
 }
 
 /* memory addresses */
-static yasm_effaddr *
+static yasm_insn_operand *
 parse_memaddr(yasm_parser_nasm *parser_nasm)
 {
-    yasm_effaddr *ea;
+    yasm_insn_operand *op;
     switch (curtok) {
         case SEGREG:
         {
@@ -754,48 +795,63 @@ parse_memaddr(yasm_parser_nasm *parser_nasm)
                 return NULL;
             }
             get_next_token();
-            ea = parse_memaddr(parser_nasm);
-            if (ea)
-                yasm_ea_set_segreg(ea, segreg);
-            return ea;
+            op = parse_memaddr(parser_nasm);
+            if (op)
+                yasm_ea_set_segreg(op->data.ea, segreg);
+            return op;
         }
         case SIZE_OVERRIDE:
         {
             unsigned int size = SIZE_OVERRIDE_val;
             get_next_token();
-            ea = parse_memaddr(parser_nasm);
-            if (ea)
-                ea->disp.size = size;
-            return ea;
+            op = parse_memaddr(parser_nasm);
+            if (op)
+                op->data.ea->disp.size = size;
+            return op;
         }
         case NOSPLIT:
             get_next_token();
-            ea = parse_memaddr(parser_nasm);
-            if (ea)
-                ea->nosplit = 1;
-            return ea;
+            op = parse_memaddr(parser_nasm);
+            if (op)
+                op->data.ea->nosplit = 1;
+            return op;
         case REL:
             get_next_token();
-            ea = parse_memaddr(parser_nasm);
-            if (ea) {
-                ea->pc_rel = 1;
-                ea->not_pc_rel = 0;
+            op = parse_memaddr(parser_nasm);
+            if (op) {
+                op->data.ea->pc_rel = 1;
+                op->data.ea->not_pc_rel = 0;
             }
-            return ea;
+            return op;
         case ABS:
             get_next_token();
-            ea = parse_memaddr(parser_nasm);
-            if (ea) {
-                ea->pc_rel = 0;
-                ea->not_pc_rel = 1;
+            op = parse_memaddr(parser_nasm);
+            if (op) {
+                op->data.ea->pc_rel = 0;
+                op->data.ea->not_pc_rel = 1;
             }
-            return ea;
+            return op;
         default:
         {
-            yasm_expr *e = parse_expr(parser_nasm, NORM_EXPR);
+            yasm_expr *e = parse_bexpr(parser_nasm, NORM_EXPR);
             if (!e)
                 return NULL;
-            return yasm_arch_ea_create(p_object->arch, e);
+            if (curtok != ':')
+                return yasm_operand_create_mem(
+                    yasm_arch_ea_create(p_object->arch, e));
+            else {
+                yasm_expr *off;
+                get_next_token();
+                off = parse_bexpr(parser_nasm, NORM_EXPR);
+                if (!off) {
+                    yasm_expr_destroy(e);
+                    return NULL;
+                }
+                op = yasm_operand_create_mem(
+                    yasm_arch_ea_create(p_object->arch, off));
+                op->seg = e;
+                return op;
+            }
         }
     }
 }
@@ -828,6 +884,9 @@ parse_memaddr(yasm_parser_nasm *parser_nasm)
             get_next_token();                           \
             f = rightfunc(parser_nasm, type);           \
             if (!f) {                                   \
+                yasm_error_set(YASM_ERROR_SYNTAX,       \
+                               N_("expected expression after %s"), \
+                               describe_token(op));     \
                 yasm_expr_destroy(e);                   \
                 return NULL;                            \
             }                                           \
@@ -840,14 +899,11 @@ static yasm_expr *
 parse_expr(yasm_parser_nasm *parser_nasm, expr_type type)
 {
     switch (type) {
-        case NORM_EXPR:
-            parse_expr_common(parse_bexpr, ':', parse_bexpr, YASM_EXPR_SEGOFF);
-        case DV_EXPR:
-            /* dataval expressions can't handle seg:off */
-            return parse_bexpr(parser_nasm, type);
         case DIR_EXPR:
             /* directive expressions can't handle seg:off or WRT */
             return parse_expr0(parser_nasm, type);
+        default:
+            parse_expr_common(parse_bexpr, ':', parse_bexpr, YASM_EXPR_SEGOFF);
     }
     /*@notreached@*/
     return NULL;
@@ -890,6 +946,9 @@ parse_expr3(yasm_parser_nasm *parser_nasm, expr_type type)
         get_next_token();
         f = parse_expr4(parser_nasm, type);
         if (!f) {
+            yasm_error_set(YASM_ERROR_SYNTAX,
+                           N_("expected expression after %s"),
+                           describe_token(op));
             yasm_expr_destroy(e);
             return NULL;
         }
@@ -915,6 +974,9 @@ parse_expr4(yasm_parser_nasm *parser_nasm, expr_type type)
         get_next_token();
         f = parse_expr5(parser_nasm, type);
         if (!f) {
+            yasm_error_set(YASM_ERROR_SYNTAX,
+                           N_("expected expression after %s"),
+                           describe_token(op));
             yasm_expr_destroy(e);
             return NULL;
         }
@@ -941,6 +1003,9 @@ parse_expr5(yasm_parser_nasm *parser_nasm, expr_type type)
         get_next_token();
         f = parse_expr6(parser_nasm, type);
         if (!f) {
+            yasm_error_set(YASM_ERROR_SYNTAX,
+                           N_("expected expression after %s"),
+                           describe_token(op));
             yasm_expr_destroy(e);
             return NULL;
         }
@@ -968,14 +1033,20 @@ parse_expr6(yasm_parser_nasm *parser_nasm, expr_type type)
         case '~':
             get_next_token();
             e = parse_expr6(parser_nasm, type);
-            if (!e)
+            if (!e) {
+                yasm_error_set(YASM_ERROR_SYNTAX,
+                               N_("expected expression after %s"), "`~'");
                 return NULL;
+            }
             return p_expr_new_branch(YASM_EXPR_NOT, e);
         case '(':
             get_next_token();
             e = parse_expr(parser_nasm, type);
-            if (!e)
+            if (!e) {
+                yasm_error_set(YASM_ERROR_SYNTAX,
+                               N_("expected expression after %s"), "`('");
                 return NULL;
+            }
             if (!expect(')')) {
                 yasm_error_set(YASM_ERROR_SYNTAX, N_("missing parenthesis"));
                 return NULL;
@@ -999,30 +1070,47 @@ parse_expr6(yasm_parser_nasm *parser_nasm, expr_type type)
     } else switch (curtok) {
         case '+':
             get_next_token();
-            return parse_expr6(parser_nasm, type);
+            e = parse_expr6(parser_nasm, type);
+            if (!e) {
+                yasm_error_set(YASM_ERROR_SYNTAX,
+                               N_("expected expression after %s"), "`+'");
+            }
+            return e;
         case '-':
             get_next_token();
             e = parse_expr6(parser_nasm, type);
-            if (!e)
+            if (!e) {
+                yasm_error_set(YASM_ERROR_SYNTAX,
+                               N_("expected expression after %s"), "`-'");
                 return NULL;
+            }
             return p_expr_new_branch(YASM_EXPR_NEG, e);
         case '~':
             get_next_token();
             e = parse_expr6(parser_nasm, type);
-            if (!e)
+            if (!e) {
+                yasm_error_set(YASM_ERROR_SYNTAX,
+                               N_("expected expression after %s"), "`~'");
                 return NULL;
+            }
             return p_expr_new_branch(YASM_EXPR_NOT, e);
         case SEG:
             get_next_token();
             e = parse_expr6(parser_nasm, type);
-            if (!e)
+            if (!e) {
+                yasm_error_set(YASM_ERROR_SYNTAX,
+                               N_("expected expression after %s"), "SEG");
                 return NULL;
+            }
             return p_expr_new_branch(YASM_EXPR_SEG, e);
         case '(':
             get_next_token();
             e = parse_expr(parser_nasm, type);
-            if (!e)
+            if (!e) {
+                yasm_error_set(YASM_ERROR_SYNTAX,
+                               N_("expected expression after %s"), "`('");
                 return NULL;
+            }
             if (!expect(')')) {
                 yasm_error_set(YASM_ERROR_SYNTAX, N_("missing parenthesis"));
                 return NULL;
@@ -1048,9 +1136,17 @@ parse_expr6(yasm_parser_nasm *parser_nasm, expr_type type)
                 yasm_intnum_create_charconst_nasm(STRING_val.contents)));
             yasm_xfree(STRING_val.contents);
             break;
-        case ID:
         case SPECIAL_ID:
+            sym = yasm_objfmt_get_special_sym(p_object, ID_val+2, "nasm");
+            if (sym) {
+                e = p_expr_new_ident(yasm_expr_sym(sym));
+                yasm_xfree(ID_val);
+                break;
+            }
+            /*@fallthrough@*/
+        case ID:
         case LOCAL_ID:
+        case NONLOCAL_ID:
             sym = yasm_symtab_use(p_symtab, ID_val, cur_line);
             e = p_expr_new_ident(yasm_expr_sym(sym));
             yasm_xfree(ID_val);
